@@ -94,6 +94,11 @@ sub brik_properties {
          'Metabrik::System::File' => [ ],
          'Metabrik::Network::Address' => [ ],
       },
+      need_packages => {
+         ubuntu => [ qw(liblwp-protocol-https-perl) ],
+         debian => [ qw(liblwp-protocol-https-perl) ],
+         kali => [ qw(liblwp-protocol-https-perl) ],
+      },
       optional_modules => {
          'WWW::Mechanize::PhantomJS' => [ ],
       },
@@ -827,7 +832,7 @@ Metabrik::Client::Www - client::www Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2020, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2022, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
